@@ -83,9 +83,11 @@ class GDocsBackend(duplicity.backend.Backend):
         # (see http://googleappsdeveloper.blogspot.com/2011/05/upload-all-file-types-to-any-google.html)
         file = source_path.open()
         uploader = gdata.client.ResumableUploader(
-          self.client, file, GDocsBackend.BACKUP_DOCUMENT_TYPE, os.path.getsize(file.name),
-          chunk_size=gdata.client.ResumableUploader.DEFAULT_CHUNK_SIZE,
-          desired_class=gdata.docs.data.Resource)
+            self.client, file,
+            GDocsBackend.BACKUP_DOCUMENT_TYPE,
+            os.path.getsize(file.name),
+            chunk_size=gdata.client.ResumableUploader.DEFAULT_CHUNK_SIZE,
+            desired_class=gdata.docs.data.Resource)
         if uploader:
             # Chunked upload.
             entry = gdata.docs.data.Resource(title=atom.data.Title(text=remote_filename))
@@ -183,4 +185,4 @@ class GDocsBackend(duplicity.backend.Backend):
         return result
 
 duplicity.backend.register_backend('gdocs', GDocsBackend)
-duplicity.backend.uses_netloc.extend([ 'gdocs' ])
+duplicity.backend.uses_netloc.extend(['gdocs'])
