@@ -22,7 +22,8 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import base64
-import httplib, os
+import httplib
+import os
 import re
 import urllib
 import urllib2
@@ -35,6 +36,7 @@ from duplicity import log
 from duplicity import util
 from duplicity.errors import BackendException, FatalBackendException
 
+
 class CustomMethodRequest(urllib2.Request):
     """
     This request subclass allows explicit specification of
@@ -48,30 +50,33 @@ class CustomMethodRequest(urllib2.Request):
     def get_method(self):
         return self.method
 
+
 class VerifiedHTTPSConnection(httplib.HTTPSConnection):
         def __init__(self, *args, **kwargs):
             try:
                 global socket, ssl
-                import socket, ssl
+                import socket
+                import ssl
             except ImportError:
                 raise FatalBackendException("Missing socket or ssl libraries.")
 
             httplib.HTTPSConnection.__init__(self, *args, **kwargs)
 
             self.cacert_file = globals.ssl_cacert_file
-            cacert_candidates = [ "~/.duplicity/cacert.pem", \
-                             "~/duplicity_cacert.pem", \
-                             "/etc/duplicity/cacert.pem" ]
+            cacert_candidates = ["~/.duplicity/cacert.pem",
+                                 "~/duplicity_cacert.pem",
+                                 "/etc/duplicity/cacert.pem"]
             #
             if not self.cacert_file:
-                for path in cacert_candidates :
+                for path in cacert_candidates:
                     path = os.path.expanduser(path)
                     if (os.path.isfile(path)):
                         self.cacert_file = path
                         break
             # still no cacert file, inform user
             if not self.cacert_file:
-                raise FatalBackendException("""For certificate verification a cacert database file is needed in one of these locations: %s
+                raise FatalBackendException("""\
+For certificate verification a cacert database file is needed in one of these locations: %s
 Hints:
   Consult the man page, chapter 'SSL Certificate Verification'.
   Consider using the options --ssl-cacert-file, --ssl-no-check-certificate .""" % ", ".join(cacert_candidates))
@@ -158,7 +163,8 @@ class WebDAVBackend(duplicity.backend.Backend):
         # "[Errno 32] Broken pipe" or SSl errors that render the connection unusable
         """
         if not forced and self.conn \
-            and self.conn.host == self.parsed_url.hostname: return
+                and self.conn.host == self.parsed_url.hostname:
+            return
 
         log.Info("WebDAV create connection on '%s'" % (self.parsed_url.hostname))
         self._close()
@@ -221,8 +227,6 @@ class WebDAVBackend(duplicity.backend.Backend):
 
         return response
 
-
-
     def get_authorization(self, response, path):
         """
         Fetches the auth header based on the requested method (basic or digest)
@@ -299,7 +303,8 @@ class WebDAVBackend(duplicity.backend.Backend):
         except Exception as e:
             raise e
         finally:
-            if response: response.close()
+            if response:
+                response.close()
 
     def makedir(self):
         """Make (nested) directories on the server."""
@@ -382,7 +387,8 @@ class WebDAVBackend(duplicity.backend.Backend):
         except Exception as e:
             raise e
         finally:
-            if response: response.close()
+            if response:
+                response.close()
 
     def _put(self, source_path, remote_filename):
         url = self.directory + remote_filename
@@ -402,7 +408,8 @@ class WebDAVBackend(duplicity.backend.Backend):
         except Exception as e:
             raise e
         finally:
-            if response: response.close()
+            if response:
+                response.close()
 
     def _delete(self, filename):
         url = self.directory + filename
@@ -420,11 +427,11 @@ class WebDAVBackend(duplicity.backend.Backend):
         except Exception as e:
             raise e
         finally:
-            if response: response.close()
+            if response:
+                response.close()
 
 duplicity.backend.register_backend("http", WebDAVBackend)
 duplicity.backend.register_backend("https", WebDAVBackend)
 duplicity.backend.register_backend("webdav", WebDAVBackend)
 duplicity.backend.register_backend("webdavs", WebDAVBackend)
-duplicity.backend.uses_netloc.extend([ 'http', 'https', 'webdav', 'webdavs' ])
-
+duplicity.backend.uses_netloc.extend(['http', 'https', 'webdav', 'webdavs'])
