@@ -37,9 +37,11 @@ from duplicity import manifest
 from duplicity import util
 from duplicity.gpg import GPGError
 
+
 class CollectionsError(Exception):
     pass
 
+
 class BackupSet:
     """
     Backup set - the backup information produced by one session
@@ -99,7 +101,7 @@ class BackupSet:
         else:
             assert pr.volume_number is not None
             assert pr.volume_number not in self.volume_name_dict, \
-                   (self.volume_name_dict, filename)
+                (self.volume_name_dict, filename)
             self.volume_name_dict[pr.volume_number] = filename
 
         return True
@@ -137,7 +139,7 @@ class BackupSet:
                     and pr.start_time == self.start_time
                     and pr.end_time == self.end_time):
                 self.local_manifest_path = \
-                              globals.archive_dir.append(local_filename)
+                    globals.archive_dir.append(local_filename)
                 break
 
     def delete(self):
@@ -315,12 +317,12 @@ class BackupChain:
                 log.Info(_("Preferring Backupset over previous one!"))
                 self.incset_list[-1] = incset
             else:
-                log.Info(_("Ignoring incremental Backupset (start_time: %s; needed: %s)") % 
+                log.Info(_("Ignoring incremental Backupset (start_time: %s; needed: %s)") %
                          (dup_time.timetopretty(incset.start_time),
                           dup_time.timetopretty(self.end_time)))
                 return False
         self.end_time = incset.end_time
-        log.Info(_("Added incremental Backupset (start_time: %s / end_time: %s)") % 
+        log.Info(_("Added incremental Backupset (start_time: %s / end_time: %s)") %
                  (dup_time.timetopretty(incset.start_time),
                   dup_time.timetopretty(incset.end_time)))
         assert self.end_time
@@ -363,7 +365,7 @@ class BackupChain:
         suitable for log messages.
         """
         return "[%s]-[%s]" % (dup_time.timetopretty(self.start_time),
-                      dup_time.timetopretty(self.end_time))
+                              dup_time.timetopretty(self.end_time))
 
     def to_log_info(self, prefix=''):
         """
@@ -392,9 +394,9 @@ class BackupChain:
         l = ["-------------------------",
              _("Chain start time: ") + dup_time.timetopretty(self.start_time),
              _("Chain end time: ") + dup_time.timetopretty(self.end_time),
-             _("Number of contained backup sets: %d") % 
+             _("Number of contained backup sets: %d") %
              (len(self.incset_list) + 1,),
-             _("Total number of contained volumes: %d") % 
+             _("Total number of contained volumes: %d") %
              (self.get_num_volumes(),),
              set_schema % (_("Type of backup set:"), _("Time:"), _("Num volumes:"))]
 
@@ -622,17 +624,17 @@ class CollectionsStatus:
         """
         l = [_("Collection Status"),
              u"-----------------",
-             _("Connecting with backend: %s") % 
+             _("Connecting with backend: %s") %
              (self.backend.__class__.__name__,),
              _("Archive dir: %s") % (util.ufn(self.archive_dir.name),)]
 
-        l.append("\n" + 
+        l.append("\n" +
                  ngettext("Found %d secondary backup chain.",
                           "Found %d secondary backup chains.",
                           len(self.other_backup_chains))
                  % len(self.other_backup_chains))
         for i in range(len(self.other_backup_chains)):
-            l.append(_("Secondary chain %d of %d:") % 
+            l.append(_("Secondary chain %d of %d:") %
                      (i + 1, len(self.other_backup_chains)))
             l.append(unicode(self.other_backup_chains[i]))
             l.append("")
@@ -675,14 +677,14 @@ class CollectionsStatus:
         backend_filename_list = self.backend.list()
         log.Debug(ngettext("%d file exists on backend",
                            "%d files exist on backend",
-                           len(backend_filename_list)) % 
+                           len(backend_filename_list)) %
                   len(backend_filename_list))
 
         # get local filename list
         local_filename_list = self.archive_dir.listdir()
         log.Debug(ngettext("%d file exists in cache",
                            "%d files exist in cache",
-                           len(local_filename_list)) % 
+                           len(local_filename_list)) %
                   len(local_filename_list))
 
         # check for partial backups
@@ -694,17 +696,17 @@ class CollectionsStatus:
 
         # get various backup sets and chains
         (backup_chains, self.orphaned_backup_sets,
-                 self.incomplete_backup_sets) = \
-                 self.get_backup_chains(partials + backend_filename_list)
+         self.incomplete_backup_sets) = \
+            self.get_backup_chains(partials + backend_filename_list)
         backup_chains = self.get_sorted_chains(backup_chains)
         self.all_backup_chains = backup_chains
 
         assert len(backup_chains) == len(self.all_backup_chains), "get_sorted_chains() did something more than re-ordering"
 
         local_sig_chains, self.local_orphaned_sig_names = \
-                            self.get_signature_chains(True)
+            self.get_signature_chains(True)
         remote_sig_chains, self.remote_orphaned_sig_names = \
-                            self.get_signature_chains(False, filelist=backend_filename_list)
+            self.get_signature_chains(False, filelist=backend_filename_list)
         self.set_matched_chain_pair(local_sig_chains + remote_sig_chains,
                                     backup_chains)
         self.warn(sig_chain_warning)
@@ -740,7 +742,7 @@ class CollectionsStatus:
                     continue
 
                 # Found a matching pair:
-                if self.matched_chain_pair == None:
+                if self.matched_chain_pair is None:
                     self.matched_chain_pair = (sig_chains[i], latest_backup_chain)
 
                 break
@@ -802,6 +804,7 @@ class CollectionsStatus:
                   % [util.ufn(f) for f in filename_list])
         # First put filenames in set form
         sets = []
+
         def add_to_sets(filename):
             """
             Try adding filename to existing sets, or make new one
@@ -817,11 +820,13 @@ class CollectionsStatus:
                     sets.append(new_set)
                 else:
                     log.Debug(_("Ignoring file (rejected by backup set) '%s'") % util.ufn(filename))
+
         for f in filename_list:
             add_to_sets(f)
         sets, incomplete_sets = self.get_sorted_sets(sets)
 
         chains, orphaned_sets = [], []
+
         def add_to_chains(set):
             """
             Try adding set to existing chains, or make new one
@@ -836,7 +841,7 @@ class CollectionsStatus:
                 for chain in chains:
                     if chain.add_inc(set):
                         log.Debug(_("Added set %s to pre-existing chain %s") % (set.get_timestr(),
-                                                     chain.short_desc()))
+                                                                                chain.short_desc()))
                         break
                 else:
                     log.Debug(_("Found orphaned set %s") % (set.get_timestr(),))
@@ -1042,11 +1047,11 @@ class CollectionsStatus:
         assert self.values_set
         old_chains = []
         for chain in self.all_backup_chains:
-            if chain.end_time < t and (
-                not self.matched_chain_pair or
-                chain is not self.matched_chain_pair[1]):
-                # don't delete the active (matched) chain
-                old_chains.append(chain)
+            if (chain.end_time < t and
+                (not self.matched_chain_pair or
+                 chain is not self.matched_chain_pair[1])):
+                    # don't delete the active (matched) chain
+                    old_chains.append(chain)
         return old_chains
 
     def get_signature_chains_older_than(self, t):
@@ -1062,11 +1067,11 @@ class CollectionsStatus:
         assert self.values_set
         old_chains = []
         for chain in self.all_sig_chains:
-            if chain.end_time < t and (
-                not self.matched_chain_pair or
-                chain is not self.matched_chain_pair[0]):
-                # don't delete the active (matched) chain
-                old_chains.append(chain)
+            if (chain.end_time < t and
+                (not self.matched_chain_pair or
+                 chain is not self.matched_chain_pair[0])):
+                    # don't delete the active (matched) chain
+                    old_chains.append(chain)
         return old_chains
 
     def get_last_full_backup_time(self):
