@@ -66,12 +66,14 @@ commands = ["cleanup",
             "verify",
             ]
 
+
 def old_fn_deprecation(opt):
     log.Log(_("Warning: Option %s is pending deprecation "
               "and will be removed in a future release.\n"
               "Use of default filenames is strongly suggested.") % opt,
             log.ERROR, force_print=True)
 
+
 def expand_fn(filename):
     return os.path.expanduser(os.path.expandvars(filename))
 
@@ -106,15 +108,18 @@ def generate_default_backup_name(backend_url):
     burlhash.update(backend_url)
     return burlhash.hexdigest()
 
+
 def check_file(option, opt, value):
     return expand_fn(value)
 
+
 def check_time(option, opt, value):
     try:
         return dup_time.genstrtotime(value)
     except dup_time.TimeException as e:
         raise optparse.OptionValueError(str(e))
 
+
 def check_verbosity(option, opt, value):
     fail = False
 
@@ -182,7 +187,10 @@ See:
     http://bugs.python.org/issue2931
     http://mail.python.org/pipermail/python-dev/2006-May/065458.html
 """
+
+
 class OPHelpFix(optparse.OptionParser):
+
     def _get_encoding(self, file):
         """
         try to get the encoding or use UTF-8
@@ -316,6 +324,10 @@ def parse_cmdline_options(arglist):
     parser.add_option("--exclude-regexp", metavar=_("regular_expression"),
                       dest="", type="string", action="callback", callback=add_selection)
 
+    # Exclude any files with modification dates older than this from the backup
+    parser.add_option("--exclude-older-than", type="time", metavar=_("time"),
+                      dest="", action="callback", callback=add_selection)
+
     # Whether we should be particularly aggressive when cleaning up
     parser.add_option("--extra-clean", action="store_true")
 
@@ -360,7 +372,7 @@ def parse_cmdline_options(arglist):
 
     parser.add_option("--gio", action="callback", dest="use_gio",
                       callback=lambda o, s, v, p: (setattr(p.values, o.dest, True),
-                                                     old_fn_deprecation(s)))
+                                                   old_fn_deprecation(s)))
 
     parser.add_option("--gpg-options", action="extend", metavar=_("options"))
 
@@ -384,8 +396,7 @@ def parse_cmdline_options(arglist):
     # Whether to use the full email address as the user name when
     # logging into an imap server. If false just the user name
     # part of the email address is used.
-    parser.add_option("--imap-full-address", action="store_true",
-                      help=optparse.SUPPRESS_HELP)
+    parser.add_option("--imap-full-address", action="store_true")
 
     # Name of the imap folder where we want to store backups.
     # Can be changed with a command line argument.
@@ -505,7 +516,7 @@ def parse_cmdline_options(arglist):
 
     # Number of seconds to wait for each part of a multipart upload to S3. Use this
     # to prevent hangups when doing a multipart upload to S3.
-    parser.add_option("--s3_multipart_max_timeout", type="int", metavar=_("number"))
+    parser.add_option("--s3-multipart-max-timeout", type="int", metavar=_("number"))
 
     # Option to allow the s3/boto backend use the multiprocessing version.
     parser.add_option("--s3-use-multiprocessing", action="store_true")
@@ -634,9 +645,9 @@ def parse_cmdline_options(arglist):
         globals.remove_time = dup_time.genstrtotime(arg)
         num_expect = 1
     elif cmd == "remove-all-but-n-full" or cmd == "remove-all-inc-of-but-n-full":
-        if cmd == "remove-all-but-n-full" :
+        if cmd == "remove-all-but-n-full":
             globals.remove_all_but_n_full_mode = True
-        if cmd == "remove-all-inc-of-but-n-full" :
+        if cmd == "remove-all-inc-of-but-n-full":
             globals.remove_all_inc_of_but_n_full_mode = True
         try:
             arg = args.pop(0)
@@ -685,7 +696,7 @@ def parse_cmdline_options(arglist):
 
 def command_line_error(message):
     """Indicate a command line error and exit"""
-    log.FatalError(_("Command line error: %s") % (message,) + "\n" + 
+    log.FatalError(_("Command line error: %s") % (message,) + "\n" +
                    _("Enter 'duplicity --help' for help screen."),
                    log.ErrorCode.command_line)
 
@@ -699,128 +710,129 @@ def usage():
     dict = {
         # TRANSL: Used in usage help to represent a Unix-style path name. Example:
         # rsync://user[:password]@other_host[:port]//absolute_path
-        'absolute_path'  : _("absolute_path"),
+        'absolute_path': _("absolute_path"),
 
         # TRANSL: Used in usage help. Example:
         # tahoe://alias/some_dir
-        'alias'          : _("alias"),
+        'alias': _("alias"),
 
         # TRANSL: Used in help to represent a "bucket name" for Amazon Web
         # Services' Simple Storage Service (S3). Example:
         # s3://other.host/bucket_name[/prefix]
-        'bucket_name'    : _("bucket_name"),
+        'bucket_name': _("bucket_name"),
 
         # TRANSL: abbreviation for "character" (noun)
-        'char'           : _("char"),
+        'char': _("char"),
 
         # TRANSL: noun
-        'command'        : _("command"),
+        'command': _("command"),
 
         # TRANSL: Used in usage help to represent the name of a container in
         # Amazon Web Services' Cloudfront. Example:
         # cf+http://container_name
-        'container_name' : _("container_name"),
+        'container_name': _("container_name"),
 
         # TRANSL: noun
-        'count'          : _("count"),
+        'count': _("count"),
 
         # TRANSL: Used in usage help to represent the name of a file directory
-        'directory'      : _("directory"),
+        'directory': _("directory"),
 
         # TRANSL: Used in usage help to represent the name of a file. Example:
         # --log-file <filename>
-        'filename'       : _("filename"),
+        'filename': _("filename"),
 
         # TRANSL: Used in usage help to represent an ID for a GnuPG key. Example:
         # --encrypt-key <gpg_key_id>
-        'gpg_key_id'     : _("gpg-key-id"),
+        'gpg_key_id': _("gpg-key-id"),
 
         # TRANSL: Used in usage help, e.g. to represent the name of a code
         # module. Example:
         # rsync://user[:password]@other.host[:port]::/module/some_dir
-        'module'         : _("module"),
+        'module': _("module"),
 
         # TRANSL: Used in usage help to represent a desired number of
         # something. Example:
         # --num-retries <number>
-        'number'         : _("number"),
+        'number': _("number"),
 
         # TRANSL: Used in usage help. (Should be consistent with the "Options:"
         # header.) Example:
         # duplicity [full|incremental] [options] source_dir target_url
-        'options'        : _("options"),
+        'options': _("options"),
 
         # TRANSL: Used in usage help to represent an internet hostname. Example:
         # ftp://user[:password]@other.host[:port]/some_dir
-        'other_host'     : _("other.host"),
+        'other_host': _("other.host"),
 
         # TRANSL: Used in usage help. Example:
         # ftp://user[:password]@other.host[:port]/some_dir
-        'password'       : _("password"),
+        'password': _("password"),
 
         # TRANSL: Used in usage help to represent a Unix-style path name. Example:
         # --archive-dir <path>
-        'path'           : _("path"),
+        'path': _("path"),
 
         # TRANSL: Used in usage help to represent a TCP port number. Example:
         # ftp://user[:password]@other.host[:port]/some_dir
-        'port'           : _("port"),
+        'port': _("port"),
 
         # TRANSL: Used in usage help. This represents a string to be used as a
         # prefix to names for backup files created by Duplicity. Example:
         # s3://other.host/bucket_name[/prefix]
-        'prefix'         : _("prefix"),
+        'prefix': _("prefix"),
 
         # TRANSL: Used in usage help to represent a Unix-style path name. Example:
         # rsync://user[:password]@other.host[:port]/relative_path
-        'relative_path'  : _("relative_path"),
+        'relative_path': _("relative_path"),
 
         # TRANSL: Used in usage help. Example:
         # --timeout <seconds>
-        'seconds'        : _("seconds"),
+        'seconds': _("seconds"),
 
         # TRANSL: Used in usage help to represent a "glob" style pattern for
         # matching one or more files, as described in the documentation.
         # Example:
         # --exclude <shell_pattern>
-        'shell_pattern'  : _("shell_pattern"),
+        'shell_pattern': _("shell_pattern"),
 
         # TRANSL: Used in usage help to represent the name of a single file
         # directory or a Unix-style path to a directory. Example:
         # file:///some_dir
-        'some_dir'       : _("some_dir"),
+        'some_dir': _("some_dir"),
 
         # TRANSL: Used in usage help to represent the name of a single file
         # directory or a Unix-style path to a directory where files will be
         # coming FROM. Example:
         # duplicity [full|incremental] [options] source_dir target_url
-        'source_dir'     : _("source_dir"),
+        'source_dir': _("source_dir"),
 
         # TRANSL: Used in usage help to represent a URL files will be coming
         # FROM. Example:
         # duplicity [restore] [options] source_url target_dir
-        'source_url'     : _("source_url"),
+        'source_url': _("source_url"),
 
         # TRANSL: Used in usage help to represent the name of a single file
         # directory or a Unix-style path to a directory. where files will be
         # going TO. Example:
         # duplicity [restore] [options] source_url target_dir
-        'target_dir'     : _("target_dir"),
+        'target_dir': _("target_dir"),
 
         # TRANSL: Used in usage help to represent a URL files will be going TO.
         # Example:
         # duplicity [full|incremental] [options] source_dir target_url
-        'target_url'     : _("target_url"),
+        'target_url': _("target_url"),
 
         # TRANSL: Used in usage help to represent a time spec for a previous
         # point in time, as described in the documentation. Example:
         # duplicity remove-older-than time [options] target_url
-        'time'           : _("time"),
+        'time': _("time"),
 
         # TRANSL: Used in usage help to represent a user name (i.e. login).
         # Example:
         # ftp://user[:password]@other.host[:port]/some_dir
-        'user'           : _("user") }
+        'user': _("user")
+    }
 
     # TRANSL: Header in usage help
     msg = """
@@ -856,6 +868,7 @@ def usage():
   webdav://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
   webdavs://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
   gdocs://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
+  pydrive://%(user)s@%(other_host)s/%(some_dir)s
   mega://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
   copy://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
   dpbx:///%(some_dir)s
@@ -921,8 +934,8 @@ def args_to_path_backend(arg1, arg2):
     arg1_is_backend, arg2_is_backend = backend.is_backend_url(arg1), backend.is_backend_url(arg2)
 
     if not arg1_is_backend and not arg2_is_backend:
-        command_line_error(
-"""One of the arguments must be an URL.  Examples of URL strings are
+        command_line_error("""\
+One of the arguments must be an URL.  Examples of URL strings are
 "scp://user@host.net:1234/path" and "file:///usr/local".  See the man
 page for more information.""")
     if arg1_is_backend and arg2_is_backend:
@@ -963,7 +976,7 @@ def process_local_dir(action, local_pathname):
                            log.ErrorCode.restore_dir_exists)
     elif action == "verify":
         if not local_path.exists():
-            log.FatalError(_("Verify directory %s does not exist") % 
+            log.FatalError(_("Verify directory %s does not exist") %
                            (util.ufn(local_path.name),),
                            log.ErrorCode.verify_dir_doesnt_exist)
     else:
@@ -979,6 +992,7 @@ def process_local_dir(action, local_pathname):
 def check_consistency(action):
     """Final consistency check, see if something wrong with command line"""
     global full_backup, select_opts, list_current
+
     def assert_only_one(arglist):
         """Raises error if two or more of the elements of arglist are true"""
         n = 0
@@ -986,6 +1000,7 @@ def check_consistency(action):
             if m:
                 n += 1
         assert n <= 1, "Invalid syntax, two conflicting modes specified"
+
     if action in ["list-current", "collection-status",
                   "cleanup", "remove-old", "remove-all-but-n-full", "remove-all-inc-of-but-n-full"]:
         assert_only_one([list_current, collection_status, cleanup,
@@ -999,13 +1014,13 @@ def check_consistency(action):
                                "restoring or verifying")
         if select_opts and action == "restore":
             log.Warn(_("Command line warning: %s") % _("Selection options --exclude/--include\n"
-                                                        "currently work only when backing up,"
-                                                        "not restoring."))
+                                                       "currently work only when backing up,"
+                                                       "not restoring."))
     else:
         assert action == "inc" or action == "full"
         if verify:
             command_line_error("--verify option cannot be used "
-                                      "when backing up")
+                               "when backing up")
         if globals.restore_dir:
             command_line_error("restore option incompatible with %s backup"
                                % (action,))
@@ -1049,7 +1064,7 @@ def ProcessCommandLine(cmdline_list):
             log.FatalError(_("""Bad URL '%s'.
 Examples of URL strings are "scp://user@host.net:1234/path" and
 "file:///usr/local".  See the man page for more information.""") % (args[0],),
-                                               log.ErrorCode.bad_url)
+                           log.ErrorCode.bad_url)
     elif len(args) == 2:
         # Figure out whether backup or restore
         backup, local_pathname = set_backend(args[0], args[1])
