@@ -38,22 +38,31 @@ MAX = 9
 
 _logger = None
 
+
 def DupToLoggerLevel(verb):
     """Convert duplicity level to the logging module's system, where higher is
        more severe"""
     return MAX - verb + 1
 
+
 def LoggerToDupLevel(verb):
     """Convert logging module level to duplicity's system, where lowere is
        more severe"""
     return DupToLoggerLevel(verb)
 
+
 def LevelName(level):
-    if   level >= 9: return "DEBUG"
-    elif level >= 5: return "INFO"
-    elif level >= 3: return "NOTICE"
-    elif level >= 1: return "WARNING"
-    else:            return "ERROR"
+    if level >= 9:
+        return "DEBUG"
+    elif level >= 5:
+        return "INFO"
+    elif level >= 3:
+        return "NOTICE"
+    elif level >= 1:
+        return "WARNING"
+    else:
+        return "ERROR"
+
 
 def Log(s, verb_level, code=1, extra=None, force_print=False):
     """Write s to stderr if verbosity level low enough"""
@@ -83,10 +92,12 @@ def Log(s, verb_level, code=1, extra=None, force_print=False):
     if force_print:
         _logger.setLevel(initial_level)
 
+
 def Debug(s):
     """Shortcut used for debug message (verbosity 9)."""
     Log(s, DEBUG)
 
+
 class InfoCode:
     """Enumeration class to hold info code values.
        These values should never change, as frontends rely upon them.
@@ -108,10 +119,12 @@ class InfoCode:
     skipping_socket = 15
     upload_progress = 16
 
+
 def Info(s, code=InfoCode.generic, extra=None):
     """Shortcut used for info messages (verbosity 5)."""
     Log(s, INFO, code, extra)
 
+
 def Progress(s, current, total=None):
     """Shortcut used for progress messages (verbosity 5)."""
     if total:
@@ -120,6 +133,7 @@ def Progress(s, current, total=None):
         controlLine = '%d' % current
     Log(s, INFO, InfoCode.progress, controlLine)
 
+
 def _ElapsedSecs2Str(secs):
     tdelta = datetime.timedelta(seconds=secs)
     hours, rem = divmod(tdelta.seconds, 3600)
@@ -130,6 +144,7 @@ def _ElapsedSecs2Str(secs):
     fmt = "%s%02d:%02d:%02d" % (fmt, hours, minutes, seconds)
     return fmt
 
+
 def _RemainingSecs2Str(secs):
     tdelta = datetime.timedelta(seconds=secs)
     hours, rem = divmod(tdelta.seconds, 3600)
@@ -161,6 +176,7 @@ def _RemainingSecs2Str(secs):
         fmt = "%dsec" % seconds
     return fmt
 
+
 def TransferProgress(progress, eta, changed_bytes, elapsed, speed, stalled):
     """Shortcut used for upload progress messages (verbosity 5)."""
     dots = int(0.4 * progress)  # int(40.0 * progress / 100.0) -- for 40 chars
@@ -173,7 +189,7 @@ def TransferProgress(progress, eta, changed_bytes, elapsed, speed, stalled):
         data_amount /= 1024.0
         data_scale = "GB"
     if stalled:
-        eta_str = "Stalled!" 
+        eta_str = "Stalled!"
         speed_amount = 0
         speed_scale = "B"
     else:
@@ -187,25 +203,28 @@ def TransferProgress(progress, eta, changed_bytes, elapsed, speed, stalled):
             speed_amount /= 1024.0
             speed_scale = "GB"
     s = "%.1f%s %s [%.1f%s/s] [%s>%s] %d%% ETA %s" % (data_amount, data_scale,
-                                                            _ElapsedSecs2Str(elapsed),
-                                                            speed_amount, speed_scale,
-                                                            '=' * dots, ' ' * (40 - dots),
-                                                            progress,
-                                                            eta_str
-                                                          )
+                                                      _ElapsedSecs2Str(elapsed),
+                                                      speed_amount, speed_scale,
+                                                      '=' * dots, ' ' * (40 - dots),
+                                                      progress,
+                                                      eta_str
+                                                      )
 
     controlLine = "%d %d %d %d %d %d" % (changed_bytes, elapsed, progress, eta, speed, stalled)
     Log(s, NOTICE, InfoCode.upload_progress, controlLine)
 
+
 def PrintCollectionStatus(col_stats, force_print=False):
     """Prints a collection status to the log"""
     Log(unicode(col_stats), 8, InfoCode.collection_status,
         '\n' + '\n'.join(col_stats.to_log_info()), force_print)
 
+
 def Notice(s):
     """Shortcut used for notice messages (verbosity 3, the default)."""
     Log(s, NOTICE)
 
+
 class WarningCode:
     """Enumeration class to hold warning code values.
        These values should never change, as frontends rely upon them.
@@ -224,10 +243,12 @@ class WarningCode:
     cannot_process = 12
     process_skipped = 13
 
+
 def Warn(s, code=WarningCode.generic, extra=None):
     """Shortcut used for warning messages (verbosity 2)"""
     Log(s, WARNING, code, extra)
 
+
 class ErrorCode:
     """Enumeration class to hold error code values.
        These values should never change, as frontends rely upon them.
@@ -293,26 +314,31 @@ class ErrorCode:
     # Reserve 127 because it is used as an error code for pkexec
     # Reserve 255 because it is used as an error code for gksu
 
+
 def Error(s, code=ErrorCode.generic, extra=None):
     """Write error message"""
     Log(s, ERROR, code, extra)
 
+
 def FatalError(s, code=ErrorCode.generic, extra=None):
     """Write fatal error message and exit"""
     Log(s, ERROR, code, extra)
     shutdown()
     sys.exit(code)
 
+
 class OutFilter(logging.Filter):
     """Filter that only allows warning or less important messages"""
     def filter(self, record):
         return record.msg and record.levelno <= DupToLoggerLevel(WARNING)
 
+
 class ErrFilter(logging.Filter):
     """Filter that only allows messages more important than warnings"""
     def filter(self, record):
         return record.msg and record.levelno > DupToLoggerLevel(WARNING)
 
+
 def setup():
     """Initialize logging"""
     global _logger
@@ -333,6 +359,7 @@ def setup():
     errHandler.addFilter(ErrFilter())
     _logger.addHandler(errHandler)
 
+
 class MachineFormatter(logging.Formatter):
     """Formatter that creates messages in a syntax easily consumable by other
        processes."""
@@ -355,12 +382,14 @@ class MachineFormatter(logging.Formatter):
         # Add a newline so consumers know the message is over.
         return s + '\n'
 
+
 class MachineFilter(logging.Filter):
     """Filter that only allows levels that are consumable by other processes."""
     def filter(self, record):
         # We only want to allow records that have our custom level names
         return hasattr(record, 'levelName')
 
+
 def add_fd(fd):
     """Add stream to which to write machine-readable logging"""
     global _logger
@@ -369,6 +398,7 @@ def add_fd(fd):
     handler.addFilter(MachineFilter())
     _logger.addHandler(handler)
 
+
 def add_file(filename):
     """Add file to which to write machine-readable logging"""
     global _logger
@@ -377,17 +407,19 @@ def add_file(filename):
     handler.addFilter(MachineFilter())
     _logger.addHandler(handler)
 
+
 def setverbosity(verb):
     """Set the verbosity level"""
     global _logger
     _logger.setLevel(DupToLoggerLevel(verb))
 
+
 def getverbosity():
     """Get the verbosity level"""
     global _logger
     return LoggerToDupLevel(_logger.getEffectiveLevel())
 
+
 def shutdown():
     """Cleanup and flush loggers"""
     logging.shutdown()
-
