@@ -38,6 +38,7 @@ from duplicity.lazy import *  # @UnusedWildImport
 
 """Functions for patching of directories"""
 
+
 class PatchDirException(Exception):
     pass
 
@@ -48,11 +49,13 @@ def Patch(base_path, difftar_fileobj):
     patch_diff_tarfile(base_path, diff_tarfile)
     assert not difftar_fileobj.close()
 
+
 def Patch_from_iter(base_path, fileobj_iter, restrict_index=()):
     """Patch given base_path and iterator of delta file objects"""
     diff_tarfile = TarFile_FromFileobjs(fileobj_iter)
     patch_diff_tarfile(base_path, diff_tarfile, restrict_index)
 
+
 def patch_diff_tarfile(base_path, diff_tarfile, restrict_index=()):
     """Patch given Path object using delta tarfile (as in tarfile.TarFile)
 
@@ -85,10 +88,12 @@ def patch_diff_tarfile(base_path, diff_tarfile, restrict_index=()):
     ITR.Finish()
     base_path.setdata()
 
+
 def empty_iter():
     if 0:
         yield 1  # this never happens, but fools into generator treatment
 
+
 def filter_path_iter(path_iter, index):
     """Rewrite path elements of path_iter so they start with index
 
@@ -103,6 +108,7 @@ def filter_path_iter(path_iter, index):
             path.index = path.index[l:]
             yield path
 
+
 def difftar2path_iter(diff_tarfile):
     """Turn file-like difftarobj into iterator of ROPaths"""
     tar_iter = iter(diff_tarfile)
@@ -139,6 +145,7 @@ def difftar2path_iter(diff_tarfile):
         yield ropath
         tarinfo_list[0] = tar_iter.next()
 
+
 def get_index_from_tarinfo(tarinfo):
     """Return (index, difftype, multivol) pair from tarinfo object"""
     for prefix in ["snapshot/", "diff/", "deleted/",
@@ -153,10 +160,10 @@ def get_index_from_tarinfo(tarinfo):
                     difftype = "snapshot"
                 multivol = 1
                 name, num_subs = \
-                      re.subn("(?s)^multivol_(diff|snapshot)/?(.*)/[0-9]+$",
-                              "\\2", tiname)
+                    re.subn("(?s)^multivol_(diff|snapshot)/?(.*)/[0-9]+$",
+                            "\\2", tiname)
                 if num_subs != 1:
-                    raise PatchDirException(u"Unrecognized diff entry %s" % 
+                    raise PatchDirException(u"Unrecognized diff entry %s" %
                                             util.ufn(tiname))
             else:
                 difftype = prefix[:-1]  # strip trailing /
@@ -166,7 +173,7 @@ def get_index_from_tarinfo(tarinfo):
                 multivol = 0
             break
     else:
-        raise PatchDirException(u"Unrecognized diff entry %s" % 
+        raise PatchDirException(u"Unrecognized diff entry %s" %
                                 util.ufn(tiname))
     if name == "." or name == "":
         index = ()
@@ -213,7 +220,7 @@ class Multivol_Filelike:
         """Add next chunk to buffer"""
         if self.at_end:
             return None
-        index, difftype, multivol = get_index_from_tarinfo(# @UnusedVariable
+        index, difftype, multivol = get_index_from_tarinfo(  # @UnusedVariable
             self.tarinfo_list[0])
         if not multivol or index != self.index:
             # we've moved on
@@ -393,6 +400,7 @@ def collate_iters(iter_list):
             yield tuple(yieldval)
     return yield_tuples(iter_num, overflow, elems)
 
+
 class IndexedTuple:
     """Like a tuple, but has .index (used previously by collate_iters)"""
     def __init__(self, index, sequence):
@@ -408,12 +416,16 @@ class IndexedTuple:
 
     def __lt__(self, other):
         return self.__cmp__(other) == -1
+
     def __le__(self, other):
         return self.__cmp__(other) != 1
+
     def __ne__(self, other):
         return not self.__eq__(other)
+
     def __gt__(self, other):
         return self.__cmp__(other) == 1
+
     def __ge__(self, other):
         return self.__cmp__(other) != -1
 
@@ -429,13 +441,14 @@ class IndexedTuple:
     def __eq__(self, other):
         if isinstance(other, IndexedTuple):
             return self.index == other.index and self.data == other.data
-        elif type(other) is types.TupleType:
+        elif isinstance(other, types.TupleType):
             return self.data == other
         else:
             return None
 
     def __str__(self):
-        return  "(%s).%s" % (", ".join(map(str, self.data)), self.index)
+        return "(%s).%s" % (", ".join(map(str, self.data)), self.index)
+
 
 def normalize_ps(patch_sequence):
     """Given an sequence of ROPath deltas, remove blank and unnecessary
@@ -458,6 +471,7 @@ def normalize_ps(patch_sequence):
         i -= 1
     return result_list
 
+
 def patch_seq2ropath(patch_seq):
     """Apply the patches in patch_seq, return single ropath"""
     first = patch_seq[0]
@@ -489,6 +503,7 @@ def patch_seq2ropath(patch_seq):
     result.setfileobj(current_file)
     return result
 
+
 def integrate_patch_iters(iter_list):
     """Combine a list of iterators of ropath patches
 
@@ -507,11 +522,12 @@ def integrate_patch_iters(iter_list):
                 yield final_ropath
         except Exception as e:
             filename = normalized[-1].get_ropath().get_relative_path()
-            log.Warn(_("Error '%s' patching %s") % 
+            log.Warn(_("Error '%s' patching %s") %
                      (util.uexc(e), util.ufn(filename)),
                      log.WarningCode.cannot_process,
                      util.escape(filename))
 
+
 def tarfiles2rop_iter(tarfile_list, restrict_index=()):
     """Integrate tarfiles of diffs into single ROPath iter
 
@@ -525,6 +541,7 @@ def tarfiles2rop_iter(tarfile_list, restrict_index=()):
         diff_iters = [filter_path_iter(x, restrict_index) for x in diff_iters]
     return integrate_patch_iters(diff_iters)
 
+
 def Write_ROPaths(base_path, rop_iter):
     """Write out ropaths in rop_iter starting at base_path
 
@@ -540,6 +557,7 @@ def Write_ROPaths(base_path, rop_iter):
     base_path.setdata()
     return return_val
 
+
 class ROPath_IterWriter(ITRBranch):
     """Used in Write_ROPaths above
 
@@ -579,7 +597,7 @@ class ROPath_IterWriter(ITRBranch):
 
     def can_fast_process(self, index, ropath):
         """Can fast process (no recursion) if ropath isn't a directory"""
-        log.Info(_("Writing %s of type %s") % 
+        log.Info(_("Writing %s of type %s") %
                  (util.ufn(ropath.get_relative_path()), ropath.type),
                  log.InfoCode.patch_file_writing,
                  "%s %s" % (util.escape(ropath.get_relative_path()), ropath.type))
