@@ -28,7 +28,12 @@ associates stat information with filenames
 
 from future_builtins import filter
 
-import stat, errno, socket, time, re, gzip
+import stat
+import errno
+import socket
+import time
+import re
+import gzip
 
 from duplicity import tarfile
 from duplicity import file_naming
@@ -44,6 +49,7 @@ from duplicity.lazy import *  # @UnusedWildImport
 _copy_blocksize = 64 * 1024
 _tmp_path_counter = 1
 
+
 class StatResult:
     """Used to emulate the output of os.stat() and related"""
     # st_mode is required by the TarInfo class, but it's unclear how
@@ -54,6 +60,7 @@ class StatResult:
 class PathException(Exception):
     pass
 
+
 class ROPath:
     """Read only Path
 
@@ -83,7 +90,7 @@ class ROPath:
         elif stat.S_ISFIFO(st_mode):
             self.type = "fifo"
         elif stat.S_ISSOCK(st_mode):
-            raise PathException(util.ufn(self.get_relative_path()) + 
+            raise PathException(util.ufn(self.get_relative_path()) +
                                 u"is a socket, unsupported by tar")
             self.type = "sock"
         elif stat.S_ISCHR(st_mode):
@@ -162,7 +169,7 @@ class ROPath:
     def open(self, mode):
         """Return fileobj associated with self"""
         assert mode == "rb" and self.fileobj and not self.opened, \
-               "%s %s %s" % (mode, self.fileobj, self.opened)
+            "%s %s %s" % (mode, self.fileobj, self.opened)
         self.opened = 1
         return self.fileobj
 
@@ -364,18 +371,18 @@ class ROPath:
             log_diff(_("File %s is missing"))
             return 0
         if self.type != other.type:
-            log_diff(_("File %%s has type %s, expected %s") % 
+            log_diff(_("File %%s has type %s, expected %s") %
                      (other.type, self.type))
             return 0
 
         if self.isreg() or self.isdir() or self.isfifo():
             if not self.perms_equal(other):
-                log_diff(_("File %%s has permissions %s, expected %s") % 
+                log_diff(_("File %%s has permissions %s, expected %s") %
                          (other.getperms(), self.getperms()))
                 return 0
             if ((int(self.stat.st_mtime) != int(other.stat.st_mtime)) and
                     (self.stat.st_mtime > 0 or other.stat.st_mtime > 0)):
-                log_diff(_("File %%s has mtime %s, expected %s") % 
+                log_diff(_("File %%s has mtime %s, expected %s") %
                          (dup_time.timetopretty(int(other.stat.st_mtime)),
                           dup_time.timetopretty(int(self.stat.st_mtime))))
                 return 0
@@ -391,12 +398,12 @@ class ROPath:
             if self.symtext == other.symtext:
                 return 1
             else:
-                log_diff(_("Symlink %%s points to %s, expected %s") % 
+                log_diff(_("Symlink %%s points to %s, expected %s") %
                          (other.symtext, self.symtext))
                 return 0
         elif self.isdev():
             if not self.perms_equal(other):
-                log_diff(_("File %%s has permissions %s, expected %s") % 
+                log_diff(_("File %%s has permissions %s, expected %s") %
                          (other.getperms(), self.getperms()))
                 return 0
             if self.devnums != other.devnums:
@@ -410,9 +417,11 @@ class ROPath:
         """Compare data from two regular files, return true if same"""
         f1 = self.open("rb")
         f2 = other.open("rb")
+
         def close():
             assert not f1.close()
             assert not f2.close()
+
         while 1:
             buf1 = f1.read(_copy_blocksize)
             buf2 = f2.read(_copy_blocksize)
@@ -647,13 +656,13 @@ class Path(ROPath):
         global _tmp_path_counter
         parent_dir = self.get_parent_dir()
         while 1:
-            temp_path = parent_dir.append("duplicity_temp." + 
+            temp_path = parent_dir.append("duplicity_temp." +
                                           str(_tmp_path_counter))
             if not temp_path.type:
                 return temp_path
             _tmp_path_counter += 1
             assert _tmp_path_counter < 10000, \
-                   u"Warning too many temp files created for " + util.ufn(self.name)
+                u"Warning too many temp files created for " + util.ufn(self.name)
 
     def compare_recursive(self, other, verbose=None):
         """Compare self to other Path, descending down directories"""
@@ -680,7 +689,8 @@ class Path(ROPath):
     def unquote(self, s):
         """Return unquoted version of string s, as quoted by above quote()"""
         assert s[0] == s[-1] == "\""  # string must be quoted by above
-        result = ""; i = 1
+        result = ""
+        i = 1
         while i < len(s) - 1:
             if s[i] == "\\":
                 result += s[i + 1]
@@ -767,9 +777,12 @@ class PathDeleter(ITRBranch):
     """Delete a directory.  Called by Path.deltree"""
     def start_process(self, index, path):
         self.path = path
+
     def end_process(self):
         self.path.delete()
+
     def can_fast_process(self, index, path):
         return not path.isdir()
+
     def fast_process(self, index, path):
         path.delete()
