@@ -40,14 +40,17 @@ documentation on what this code does can be found on the man page.
 
 """
 
+
 class SelectError(Exception):
     """Some error dealing with the Select class"""
     pass
 
+
 class FilePrefixError(SelectError):
     """Signals that a specified file doesn't start with correct prefix"""
     pass
 
+
 class GlobbingError(SelectError):
     """Something has gone wrong when parsing a glob string"""
     pass
@@ -163,7 +166,7 @@ class Select:
 
         if not path.type:
             # base doesn't exist
-            log.Warn(_("Warning: base %s doesn't exist, continuing") % 
+            log.Warn(_("Warning: base %s doesn't exist, continuing") %
                      util.ufn(path.name))
             return
         log.Debug(_("Selecting %s") % util.ufn(path.name))
@@ -245,6 +248,8 @@ class Select:
                     self.add_selection_func(self.other_filesystems_get_sf(0))
                 elif opt == "--exclude-regexp":
                     self.add_selection_func(self.regexp_get_sf(arg, 0))
+                elif opt == "--exclude-older-than":
+                    self.add_selection_func(self.exclude_older_get_sf(arg))
                 elif opt == "--include":
                     self.add_selection_func(self.glob_get_sf(arg, 1))
                 elif opt == "--include-filelist":
@@ -267,14 +272,14 @@ class Select:
     def parse_catch_error(self, exc):
         """Deal with selection error exc"""
         if isinstance(exc, FilePrefixError):
-            log.FatalError(_(
-"""Fatal Error: The file specification
+            log.FatalError(_("""\
+Fatal Error: The file specification
     %s
 cannot match any files in the base directory
     %s
 Useful file specifications begin with the base directory or some
-pattern (such as '**') which matches the base directory.""") % 
-            (exc, util.ufn(self.prefix)), log.ErrorCode.file_prefix_error)
+pattern (such as '**') which matches the base directory.""") %
+                           (exc, util.ufn(self.prefix)), log.ErrorCode.file_prefix_error)
         elif isinstance(exc, GlobbingError):
             log.FatalError(_("Fatal Error while processing expression\n"
                              "%s") % exc, log.ErrorCode.globbing_error)
@@ -285,14 +290,14 @@ pattern (such as '**') which matches the base directory.""") %
         """Exit with error if last selection function isn't an exclude"""
         if (self.selection_functions and
                 not self.selection_functions[-1].exclude):
-            log.FatalError(_(
-"""Last selection expression:
+            log.FatalError(_("""\
+Last selection expression:
     %s
 only specifies that files be included.  Because the default is to
 include all files, the expression is redundant.  Exiting because this
-probably isn't what you meant.""") % 
-            (self.selection_functions[-1].name,),
-            log.ErrorCode.redundant_inclusion)
+probably isn't what you meant.""") %
+                           (self.selection_functions[-1].name,),
+                           log.ErrorCode.redundant_inclusion)
 
     def add_selection_func(self, sel_func, add_to_start=None):
         """Add another selection function at the end or beginning"""
@@ -313,7 +318,7 @@ probably isn't what you meant.""") %
         """
         log.Notice(_("Reading filelist %s") % filelist_name)
         tuple_list, something_excluded = \
-                    self.filelist_read(filelist_fp, inc_default, filelist_name)
+            self.filelist_read(filelist_fp, inc_default, filelist_name)
         log.Notice(_("Sorting filelist %s") % filelist_name)
         tuple_list.sort()
         i = [0]  # We have to put index in list because of stupid scoping rules
@@ -323,7 +328,7 @@ probably isn't what you meant.""") %
                 if i[0] >= len(tuple_list):
                     return None
                 include, move_on = \
-                         self.filelist_pair_match(path, tuple_list[i[0]])
+                    self.filelist_pair_match(path, tuple_list[i[0]])
                 if move_on:
                     i[0] += 1
                     if include is None:
@@ -337,12 +342,13 @@ probably isn't what you meant.""") %
     def filelist_read(self, filelist_fp, include, filelist_name):
         """Read filelist from fp, return (tuplelist, something_excluded)"""
         prefix_warnings = [0]
+
         def incr_warnings(exc):
             """Warn if prefix is incorrect"""
             prefix_warnings[0] += 1
             if prefix_warnings[0] < 6:
                 log.Warn(_("Warning: file specification '%s' in filelist %s\n"
-                           "doesn't start with correct prefix %s.  Ignoring.") % 
+                           "doesn't start with correct prefix %s.  Ignoring.") %
                          (exc, filelist_name, util.ufn(self.prefix)))
                 if prefix_warnings[0] == 5:
                     log.Warn(_("Future prefix errors will not be logged."))
@@ -469,11 +475,13 @@ probably isn't what you meant.""") %
         """Return selection function matching files on other filesystems"""
         assert include == 0 or include == 1
         root_devloc = self.rootpath.getdevloc()
+
         def sel_func(path):
             if path.exists() and path.getdevloc() != root_devloc:
                 return include
             else:
                 return None
+
         sel_func.exclude = not include
         sel_func.name = "Match other filesystems"
         return sel_func
@@ -502,11 +510,13 @@ probably isn't what you meant.""") %
         if self.selection_functions:
             log.Warn(_("Warning: exclude-device-files is not the first "
                        "selector.\nThis may not be what you intended"))
+
         def sel_func(path):
             if path.isdev():
                 return 0
             else:
                 return None
+
         sel_func.exclude = 1
         sel_func.name = "Exclude device files"
         return sel_func
@@ -618,7 +628,7 @@ probably isn't what you meant.""") %
         if glob_str.find("**") != -1:
             glob_str = glob_str[:glob_str.find("**") + 2]  # truncate after **
 
-        scan_comp_re = re_comp("^(%s)$" % 
+        scan_comp_re = re_comp("^(%s)$" %
                                "|".join(self.glob_get_prefix_res(glob_str)))
 
         def include_sel_func(path):
@@ -644,6 +654,23 @@ probably isn't what you meant.""") %
         else:
             return exclude_sel_func
 
+    def exclude_older_get_sf(self, date):
+        """Return selection function based on files older than modification date """
+
+        def sel_func(path):
+            if not path.isreg():
+                return None
+            try:
+                if os.path.getmtime(path.name) < date:
+                    return 0
+            except OSError as e:
+                pass  # this is probably only on a race condition of file being deleted
+            return None
+
+        sel_func.exclude = True
+        sel_func.name = "Select older than %s" % (date,)
+        return sel_func
+
     def glob_get_prefix_res(self, glob_str):
         """Return list of regexps equivalent to prefixes of glob_str"""
         glob_parts = glob_str.split("/")
@@ -700,4 +727,3 @@ probably isn't what you meant.""") %
             else:
                 res = res + re.escape(c)
         return res
-
